@@ -1,9 +1,9 @@
-/* $Id: winio.c,v 1.581 2006/12/02 23:39:16 dolorous Exp $ */
+/* $Id: winio.c,v 1.582 2007/01/01 05:15:32 dolorous Exp $ */
 /**************************************************************************
  *   winio.c                                                              *
  *                                                                        *
  *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Chris Allegretta    *
- *   Copyright (C) 2005, 2006 David Lawrence Ramsey                       *
+ *   Copyright (C) 2005, 2006, 2007 David Lawrence Ramsey                 *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 2, or (at your option)  *
@@ -30,8 +30,8 @@
 #include <ctype.h>
 
 static int *key_buffer = NULL;
-	/* The keystroke buffer, containing all the keystrokes we have
-	 * at a given point. */
+	/* The keystroke buffer, containing all the keystrokes we
+	 * haven't handled yet at a given point. */
 static size_t key_buffer_len = 0;
 	/* The length of the keystroke buffer. */
 static int statusblank = 0;
@@ -3213,7 +3213,7 @@ void do_credits(void)
 	"",
 	"",
 	"(c) 1999, 2000, 2001, 2002, 2003, 2004 Chris Allegretta",
-	"(c) 2005, 2006 David Lawrence Ramsey",
+	"(c) 2005, 2006, 2007 David Lawrence Ramsey",
 	"",
 	"",
 	"",
